# wine_shipping

WineShipping - the Ruby gem for the API from Wineshipping

Wineshipping API is a programmatically consumable service or an Application Programming Interface (API) platform designed to enable Wineshipping LLC's client applications to natively transmit and manage their order, view inventory, track shipments etc.<br /><br />In order to access API operations request a UserKey and Password from Wineshipping. For any questions please contact Wineshipping Helpdesk at <a href='mailto:IT-Help@wineshipping.com?Subject=API from Wineshipping'>IT-Help@wineshipping.com</a>.

This SDK is automatically generated by the [Swagger Codegen](https://github.com/swagger-api/swagger-codegen) project:

- API version: V3
- Package version: 1.0.0
- Build package: io.swagger.codegen.languages.RubyClientCodegen

## Installation

### Build a gem

To build the Ruby code into a gem:

```shell
gem build wine_shipping.gemspec
```

Then either install the gem locally:

```shell
gem install ./wine_shipping-1.0.0.gem
```
(for development, run `gem install --dev ./wine_shipping-1.0.0.gem` to install the development dependencies)

or publish the gem to a gem hosting service, e.g. [RubyGems](https://rubygems.org/).

Finally add this to the Gemfile:

    gem 'wine_shipping', '~> 1.0.0'

### Install from Git

If the Ruby gem is hosted at a git repository: https://github.com/YOUR_GIT_USERNAME/YOUR_GIT_REPO, then add the following in the Gemfile:

    gem 'wine_shipping', :git => 'https://github.com/YOUR_GIT_USERNAME/YOUR_GIT_REPO.git'

### Include the Ruby code directly

Include the Ruby code directly using `-I` as follows:

```shell
ruby -Ilib script.rb
```

## Getting Started

Please follow the [installation](#installation) procedure and then run the following code:
```ruby
# Load the gem
require 'wine_shipping'

api_instance = WineShipping::InventoryApi.new

authentication_details = WineShipping::Authentication.new # Authentication | 


begin
  result = api_instance.get_inventory_details(authentication_details)
  p result
rescue WineShipping::ApiError => e
  puts "Exception when calling InventoryApi->get_inventory_details: #{e}"
end

```

## Documentation for API Endpoints

All URIs are relative to *https://wsservices-test.azurewebsites.net*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*WineShipping::InventoryApi* | [**get_inventory_details**](docs/InventoryApi.md#get_inventory_details) | **POST** /api/Inventory/GetDetails | 
*WineShipping::InventoryApi* | [**get_inventory_status**](docs/InventoryApi.md#get_inventory_status) | **POST** /api/Inventory/GetStatus | 
*WineShipping::InventoryMovementApi* | [**create_purchase_order**](docs/InventoryMovementApi.md#create_purchase_order) | **POST** /api/InventoryMovement/CreatePurchaseOrder | 
*WineShipping::InventoryMovementApi* | [**create_transfer_order**](docs/InventoryMovementApi.md#create_transfer_order) | **POST** /api/InventoryMovement/CreateTransferOrder | 
*WineShipping::SKUApi* | [**create_sku**](docs/SKUApi.md#create_sku) | **POST** /api/SKU/CreateSKU | 
*WineShipping::SalesOrderApi* | [**cancel_sales_order**](docs/SalesOrderApi.md#cancel_sales_order) | **POST** /api/SalesOrder/CancelSalesOrder | 
*WineShipping::SalesOrderApi* | [**create_sales_order**](docs/SalesOrderApi.md#create_sales_order) | **POST** /api/SalesOrder/CreateSalesOrder | 
*WineShipping::SalesOrderApi* | [**get_orders_on_hold**](docs/SalesOrderApi.md#get_orders_on_hold) | **POST** /api/SalesOrder/GetOrdersOnHold | 
*WineShipping::SalesOrderApi* | [**get_returns**](docs/SalesOrderApi.md#get_returns) | **POST** /api/SalesOrder/GetReturns | 
*WineShipping::SalesOrderApi* | [**replace_sales_order**](docs/SalesOrderApi.md#replace_sales_order) | **POST** /api/SalesOrder/ReplaceSalesOrder | 
*WineShipping::TrackingApi* | [**get_details**](docs/TrackingApi.md#get_details) | **POST** /api/Tracking/GetDetails | 


## Documentation for Models

 - [WineShipping::Authentication](docs/Authentication.md)
 - [WineShipping::BillingContactInfo](docs/BillingContactInfo.md)
 - [WineShipping::DeliveryContactInfo](docs/DeliveryContactInfo.md)
 - [WineShipping::Inventory](docs/Inventory.md)
 - [WineShipping::InventoryStatusRequest](docs/InventoryStatusRequest.md)
 - [WineShipping::InventoryStatusResult](docs/InventoryStatusResult.md)
 - [WineShipping::ItemInfo](docs/ItemInfo.md)
 - [WineShipping::OrderOnHold](docs/OrderOnHold.md)
 - [WineShipping::OrderOnHoldItem](docs/OrderOnHoldItem.md)
 - [WineShipping::PackageItem](docs/PackageItem.md)
 - [WineShipping::PurchaseOrderDetails](docs/PurchaseOrderDetails.md)
 - [WineShipping::PurchaseOrderInfo](docs/PurchaseOrderInfo.md)
 - [WineShipping::PurchaseOrderItemInfo](docs/PurchaseOrderItemInfo.md)
 - [WineShipping::RecipientContactInfo](docs/RecipientContactInfo.md)
 - [WineShipping::RequestorInfo](docs/RequestorInfo.md)
 - [WineShipping::ReturnResult](docs/ReturnResult.md)
 - [WineShipping::ReturnSalesOrderHeader](docs/ReturnSalesOrderHeader.md)
 - [WineShipping::ReturnSalesOrderLine](docs/ReturnSalesOrderLine.md)
 - [WineShipping::ReturnsRequest](docs/ReturnsRequest.md)
 - [WineShipping::SKUDetails](docs/SKUDetails.md)
 - [WineShipping::SKUInfo](docs/SKUInfo.md)
 - [WineShipping::SalesOrderCancelRequest](docs/SalesOrderCancelRequest.md)
 - [WineShipping::SalesOrderDetails](docs/SalesOrderDetails.md)
 - [WineShipping::SalesOrderInfo](docs/SalesOrderInfo.md)
 - [WineShipping::ShipmentInfo](docs/ShipmentInfo.md)
 - [WineShipping::TrackingRequest](docs/TrackingRequest.md)
 - [WineShipping::TrackingResult](docs/TrackingResult.md)
 - [WineShipping::TransferOrderDetails](docs/TransferOrderDetails.md)
 - [WineShipping::TransferOrderInfo](docs/TransferOrderInfo.md)
 - [WineShipping::TransferOrderItemInfo](docs/TransferOrderItemInfo.md)
 - [WineShipping::WarehouseInventoryStatus](docs/WarehouseInventoryStatus.md)


## Documentation for Authorization

 All endpoints do not require authorization.

